#-------------------------------------------------------------------------------
# @(#) siemens-nss/vstart/UserConfig.pm siemens-nss_r2.4.0.2:cset.001350:8:8 03/12/03 @(#)
#-------------------------------------------------------------------------------
#
# (c) Copyright IBM Corporation 2007. All rights reserved.
#
# This perl module contains the configuration information for this parser.
# If you don't understand the format of this configuration file DON'T TOUCH IT.
#
package UserConfig;

@ISA = qw(Exporter);
@EXPORT = qw(postparser_config);

#use diagnostics;
use strict;
use Exporter ();

use AudLog;

#-------------------------------------------------------------------------------
my @rules = 
(
	{
		RULE_TYPE => 'MERGELINES',
		RULE_NAME => 'USMM Group Statistics',
		INPUT_FILE_DESCRIPTION => ['^USMM-#-.*-#-I\.pif$'],
		COUNTERS_TO_SORT_ON => ['START_DATE', 'TIME'],
		PRODUCE_LIF => 0,
		PRODUCE_PIF => 'True',
	},
	
	{
		RULE_TYPE => 'PIF_2_OUTPUT',
		RULE_DESC => 'Convert all USMM PIFs and LIF',
		INPUT_FILE_DESCRIPTION  => '^USMM-#-.*-#-SM\.pif$',
		OUTPUT_BLOCK_NAME => 'USMM',
		PRODUCE_PIF => 0,
		PRODUCE_LIF => 'True',
		OUTPUT_FORMAT => 'LIF_Writer',	
	},
	
	{
		RULE_TYPE => 'USMM_TRAFFIC',
		RULE_NAME => 'Normalize the USMM block',
		INPUT_FILE_DESCRIPTION => '^USMM-#-.*-#-I\.pif$',
		OUTPUT_BLOCK_NAME => 'TRAFF',
		PRODUCE_PIF => 0,
		PRODUCE_LIF => 'True',
	},
	
	{
		RULE_TYPE => 'PIF_2_OUTPUT',
		RULE_DESC => 'Convert all USVM PIFs and LIF',
		INPUT_FILE_DESCRIPTION  => '^USVM.*pif$',
		OUTPUT_BLOCK_NAME => 'USVM',
		PRODUCE_PIF => 0,
		PRODUCE_LIF => 'True',
		OUTPUT_FORMAT => 'LIF_Writer',
	},

	{
		RULE_TYPE => 'USSM_SSID',
		RULE_NAME => 'Normalize the USSM block',
		INPUT_FILE_DESCRIPTION => '^USSM-#-.*-#-I\.pif$',
		OUTPUT_BLOCK_NAME => 'USSM_VN',
		PRODUCE_PIF => 0,
		PRODUCE_LIF => 'True',
	},
	
	{
		RULE_TYPE => 'PIF_2_OUTPUT',
		RULE_DESC => 'Convert all USSM PIFs and LIF',
		INPUT_FILE_DESCRIPTION  => '^USSM-#-.*-#-I\.pif$',
		OUTPUT_BLOCK_NAME => 'USSM',
		PRODUCE_PIF => 0,
		PRODUCE_LIF => 'True',
		OUTPUT_FORMAT => 'LIF_Writer',
	},

	{
		RULE_TYPE => 'PIF_2_OUTPUT',
		RULE_DESC => 'Convert all USWM PIFs and LIF',
		INPUT_FILE_DESCRIPTION  => '^USWM.*pif$',
		OUTPUT_BLOCK_NAME => 'USWM',
		PRODUCE_PIF => 0,
		PRODUCE_LIF => 'True',
		OUTPUT_FORMAT => 'LIF_Writer',
	},

	{
		RULE_TYPE => 'PIF_2_OUTPUT',
		RULE_DESC => 'Convert all USAM PIFs to LIF',
		INPUT_FILE_DESCRIPTION => '^USAM.*pif$',
		OUTPUT_BLOCK_NAME => 'USAM',
		PRODUCE_PIF => 0,
		PRODUCE_LIF => 'True',
		OUTPUT_FORMAT => 'LIF_Writer',
	},
	
	{
		RULE_TYPE => 'PIF_2_LIF',
		RULE_NAME => 'Mobile Measurements',
		INPUT_FILE_DESCRIPTION => "^USEM.*pif\$",
		OUTPUT_BLOCK_NAME => "USEM",
		PRODUCE_PIF => 0,
		PRODUCE_LIF => 'TRUE',
	},

	{
		RULE_TYPE => 'PIF_2_OUTPUT',
		RULE_DESC => 'Convert all USHM PIFs to LIF',
		INPUT_FILE_DESCRIPTION => '^USHM.*pif$',
		OUTPUT_BLOCK_NAME => 'USHM',
		PRODUCE_PIF => 0,
		PRODUCE_LIF => 'True',
		OUTPUT_FORMAT => 'LIF_Writer',
	},

	{
		RULE_TYPE => 'FILE_SPLIT',
		RULE_DESC => 'To split USIM PIF',
		INPUT_FILE_DESCRIPTION => '^USIM-#-.*-#-I\.pif$',
		COUNTERS_USED_TO_SPLIT_FILE => {
			TIME => '(\d{2}):\d{2}',
		},
		SPLIT_COUNTERS_ORDER => [qw(TIME)],
		OUTPUT_BLOCK_NAME => 'USIM',
		PRODUCE_PIF => 0,
		PRODUCE_LIF => 'True',
	},
	
	{
		RULE_TYPE => 'PIF_2_OUTPUT',
		RULE_DESC => 'Convert all USLM PIFs and LIF',
		INPUT_FILE_DESCRIPTION  => '^USLM.*pif$',
		OUTPUT_BLOCK_NAME => 'USLM',
		PRODUCE_PIF => 0,
		PRODUCE_LIF => 'True',
		OUTPUT_FORMAT => 'LIF_Writer',
	},	

	{
		RULE_TYPE => 'FILE_SPLIT',
		RULE_DESC => 'To split USTM PIF',
		INPUT_FILE_DESCRIPTION => '^USTM-#-.*-#-I\.pif$',
		COUNTERS_USED_TO_SPLIT_FILE => {
			TIME => '(\d{2}):\d{2}',
		},
		SPLIT_COUNTERS_ORDER => [qw(TIME)],
		OUTPUT_BLOCK_NAME => 'USTM',
		PRODUCE_PIF => 0,
		PRODUCE_LIF => 'True',
	},
	
	#
	# The next five rules process all the CCS7 Traffic
	# measurement types
	#
	{
		RULE_TYPE => 'PIF_2_LIF',
		RULE_NAME => 'C7DCDMSU',
		INPUT_FILE_DESCRIPTION => "^C7DM.*pif\$",
		PRODUCE_PIF => 0,
		PRODUCE_LIF => 'TRUE',
	},
	
	{
		RULE_TYPE => 'JOIN',
		RULE_NAME => 'C7GOS and C7LLOAD',
		OUTPUT_BLOCK_NAME => "^C7GOC7LL",
		INPUT_FILE_DESCRIPTION => [
                                      "^C7GO-#-1398-#-39-#(.*)-#-[0-9]+-#-I.pif\$",
                                      "^C7LL-#-1401-#-39-#(.*)-#-[0-9]+-#-I.pif\$", ],
		HOURS_TO_WAIT_FOR_PARTNER_FILES => 1,
		COUNTERS_TO_JOIN_ON => ["START_DATE", "TIME", "LSNAM", "LCOD"],
		NON_APPLICABLE_HEADER_COUNTERS => ["MEASURE_ID","FILENAME"],
		HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['VARIANT'],
		OUTPUT_FILENAME_START => 'C7GOC7LL',
		PRODUCE_PIF => 0,
		PRODUCE_LIF => 'TRUE',
        },
	
	{
		RULE_TYPE => 'PIF_2_LIF',
		RULE_NAME => 'C7LSET',
		INPUT_FILE_DESCRIPTION => "^C7LS.*pif\$",
		PRODUCE_PIF => 0,
		PRODUCE_LIF => 'TRUE',
	},
	
	{
		RULE_TYPE => 'PIF_2_LIF',
		RULE_NAME => 'C7MSU',
		INPUT_FILE_DESCRIPTION => "^C7MU.*pif\$",
		PRODUCE_PIF => 0,
		PRODUCE_LIF => 'TRUE',
	},

	{
		RULE_TYPE => 'PIF_2_LIF',
		RULE_NAME => 'C7RSET',
		INPUT_FILE_DESCRIPTION => "^C7RS.*pif\$",
		PRODUCE_PIF => 0,
		PRODUCE_LIF => 'TRUE',
	},

	{
		RULE_TYPE => 'MERGELINES',
		RULE_NAME => 'DEST Trunk Group Statistics',
		INPUT_FILE_DESCRIPTION => ['^DEST-#-.*-#-I\.pif$'],
		COUNTERS_TO_SORT_ON => ['START_DATE', 'TIME', 'DECO', 'ORIG'], 
		REDUNDANT_COUNTERS => ['INDEX'],
		PRODUCE_LIF => 'True',
		PRODUCE_PIF => 0,
	},

        {
                RULE_TYPE => 'FILE_SPLIT',
                RULE_NAME => 'To split DLUX PIF to DLU/DIU blocks',
                INPUT_FILE_DESCRIPTION => ['^DLUX-#-.*-#-I\.pif$'],
                COUNTERS_USED_TO_SPLIT_FILE => {
                        INDEX => '^(\d+)',
                },
                SPLIT_COUNTERS_ORDER => [qw(INDEX)],
                OUTPUT_BLOCK_NAME => "DLUX",
                PRODUCE_PIF => 'True',
                PRODUCE_LIF => 0,
        },
        {
                RULE_TYPE => 'PIF_2_OUTPUT',
                RULE_DESC => 'Renaming DLUX to DLUX_DLU blocks',
                INPUT_FILE_DESCRIPTION => ['^DLUX-#-.*-#-10-#-FS\.pif$'],
                OUTPUT_BLOCK_NAME => 'DLUX_DLU',
                PRODUCE_PIF => 0,
                PRODUCE_LIF => 'True',
                OUTPUT_FORMAT => 'LIF_Writer',
        },
        {
               RULE_TYPE => 'PIF_2_OUTPUT',
               RULE_DESC => 'Renaming DLUX to DLUX_DLU blocks',
               INPUT_FILE_DESCRIPTION => ['^DLUX-#-.*-#-20-#-FS\.pif$'],
               OUTPUT_BLOCK_NAME => 'DLUX_DLU',
               PRODUCE_PIF => 0,
               PRODUCE_LIF => 'True',
               OUTPUT_FORMAT => 'LIF_Writer',
        },
        {
               RULE_TYPE => 'PIF_2_OUTPUT',
               RULE_DESC => 'Renaming DLUX to DLUX_DIU blocks',
               INPUT_FILE_DESCRIPTION => ['^DLUX-#-.*-#-30-#-FS\.pif$'],
               OUTPUT_BLOCK_NAME => 'DLUX_DIU',
               PRODUCE_PIF => 0,
               PRODUCE_LIF => 'True',
               OUTPUT_FORMAT => 'LIF_Writer',
        },
        {
                RULE_TYPE => 'PIF_2_OUTPUT',
                RULE_DESC => 'Renaming DLUX to DLUX_DIU blocks',
                INPUT_FILE_DESCRIPTION => ['^DLUX-#-.*-#-40-#-FS\.pif$'],
                OUTPUT_BLOCK_NAME => 'DLUX_DIU',
                PRODUCE_PIF => 0,
                PRODUCE_LIF => 'True',
                OUTPUT_FORMAT => 'LIF_Writer',
        },
        {
                RULE_TYPE => 'ACCUMULATE',
                RULE_DESC => 'Aggregation of DIU Object to DLU Level',
                INPUT_FILE_DESCRIPTION => [
					'^DLUX-#-\d+-#-\d+-#-(.*)-#-I-#-(30)-#-FS\.pif$',
                                        '^DLUX-#-\d+-#-\d+-#-(.*)-#-I-#-(40)-#-FS\.pif$'
                                        ],
                COUNTERS_TO_SORT_ON => [qw(DLU START_DATE TIME)],
                NON_ADDITIVE_COUNTERS => [qw(AVAILABILITY MASK_NUMBER NO_DLUS)],
                REDUNDANT_COUNTERS => ['TSG', 'LTG', 'LTU', 'INDEX', 'SECURE_MARK'],
		OUTPUT_BLOCK_NAME => 'DLUX_DIU_agg',
                OUTPUT_FILENAME_START => 'DLUX_DIU_agg',
		PRODUCE_PIF => '0',
                PRODUCE_LIF => 'True',
        },

	{
	        RULE_TYPE => 'MERGELINES',
                RULE_NAME => 'PBXX Service Group Statistics',
                INPUT_FILE_DESCRIPTION => ['^PBXX-#-.*-#-I\.pif$'],
                COUNTERS_TO_SORT_ON => ['START_DATE', 'TIME', 'LAC', 'DN', 'SERVICE_NUMBER', 'OPMODE'],
                PRODUCE_LIF => 0,
                PRODUCE_PIF => 'True',
	},
	
	{
         	RULE_TYPE => 'PERLIZE',
         	RULE_NAME => 'Inserting Service Key into PBXX Files',
         	INPUT_FILE_DESCRIPTION => [ 'PBXX.*-#-SM\.pif$' ],
         	OUTPUT_BLOCK_NAME => 'PBXX',
         	DATA_COUNTERS_OP => sub
         	{
                   my $data = shift ;
		   
		   if ($data->{SERVICE_NUMBER} eq 0) {
			$data->{SERVICE_KEY} = 'IND';	
		   }
		   else {
			 $data->{SERVICE_KEY} = 'DEP';  
		   }
		   
		   return 0;
                },
		FILENAME_SUFFIX => 'PZ',
		PRODUCE_PIF => 'True',
		PRODUCE_LIF => 0,
        },
	
	{
                RULE_TYPE => 'FILE_SPLIT',
                RULE_DESC => 'To split PBXX PIF',
                INPUT_FILE_DESCRIPTION => ['PBXX.*-#-SM-#-PZ\.pif$'],
                COUNTERS_USED_TO_SPLIT_FILE => {
                        SERVICE_KEY => '(.*)',
                },
                SPLIT_COUNTERS_ORDER => [qw(SERVICE_KEY)],
		REDUNDANT_DATA_COUNTERS => [qw(SERVICE_KEY)],
                OUTPUT_BLOCK_NAME => 'PBXX',
                PRODUCE_PIF => 'True',
                PRODUCE_LIF => 0,
        },
	
	{
                RULE_TYPE => 'PIF_2_OUTPUT',
                RULE_DESC => 'Convert all Service Dependant PBXX PIFs and LIF',
                INPUT_FILE_DESCRIPTION => ['PBXX.*-#-SM-#-PZ-#-DEP-#-FS\.pif$'],
                OUTPUT_BLOCK_NAME => 'PBXX_DEP',
                PRODUCE_PIF => 0,
                PRODUCE_LIF => 'True',
                OUTPUT_FORMAT => 'LIF_Writer',
        },
	
	{
                RULE_TYPE => 'PIF_2_OUTPUT',
                RULE_DESC => 'Convert all Service Independant PBXX PIFs and LIF',
                INPUT_FILE_DESCRIPTION => ['PBXX.*-#-SM-#-PZ-#-IND-#-FS\.pif$'],
                OUTPUT_BLOCK_NAME => 'PBXX',
                PRODUCE_PIF => 0,
                PRODUCE_LIF => 'True',
                OUTPUT_FORMAT => 'LIF_Writer',
        },

        {
                RULE_TYPE => 'MERGELINES',
                RULE_NAME => 'ANGR Trunk Group Statistics',
                INPUT_FILE_DESCRIPTION => ['^ANGR-#-.*-#-I\.pif$'],
                COUNTERS_TO_SORT_ON => ['START_DATE', 'TIME', 'TGNO'],
		REDUNDANT_COUNTERS => ['INDEX'],
                PRODUCE_LIF => 'True',
                PRODUCE_PIF => 0,
	},

	{
		RULE_TYPE => 'PERLIZE',
		RULE_NAME => 'Tidying up INST Files',
		INPUT_FILE_DESCRIPTION => [ "^INST.*-#-I.pif\$", ],
		OUTPUT_BLOCK_NAME => 'INST',
		DATA_COUNTERS_OP => sub
		{
			my $data = shift ;
			my $ref = shift ;
			my $input_file_name = shift ;
			my $output_dir_name = shift ;
			my ($tmp) = "" ;
			my ($xname, $xvalue,$xtotal) = @$data{'COUNTER_NAME','COUNTER_VALUE','TOTAL'} ;
			$xname =~ s/[ \/]/_/gi ;
			$xname =~ s/[\.\(\)]//gi ;

			# Converting counter names to those in loadmap
			$xname =~ s/ABORTED_BY_SCP_OR_REMOTE_TCAP/ABORTED_BY_SCP_OR_REMOTE_TCAP/ ;
			$xname =~ s/ABORTED_LOCALLY_BY_SSP/LOCAL_ABORT_BY_SSP/ ;
			$xname =~ s/CONGESTED_DIALOGUES/BLOCKED_DIALOGS/ ;
			$xname =~ s/DIALOGUES_PROCESSED_TOTAL/PROCESSED_DIALOGS_OVERALL/ ;
			$xname =~ s/DIALOGUE_INITIATION_ATTEMPTS/ATTEMPTED_DIALOG_INITIATIONS/ ;
			$xname =~ s/DIAL_PROCESSED_SCF_INIT/PROCESSED_DIALOGS_SCF_INI/ ;
			$xname =~ s/ERROR_REJECT_MESSAGE_FROM_SCP/ERROR_REJECTION_MESSAGE_FROM_SCP/ ;
			$xname =~ s/ERROR_REJECT_MSG_SENT_BY_SSP/ERROR_REJECTION_MESSAGE_FROM_SSP/ ;
			$xname =~ s/MESSAGE_NOT_ACCEPTED_BY_TCAP/MESSG_FROM_TCAP_NOT_ACCEPTED/ ;
			$xname =~ s/TIMEOUT_ON_RESPONSE/TIME_FOR_ANSWER_EXPIRED/ ;

			$xvalue =~ s/\.//gi ;
			$xtotal =~ s/\.//gi ;
			$data->{COUNTER_NAME} = $xname ;
			$data->{COUNTER_VALUE} = $xvalue ;
			$data->{TOTAL} = $xtotal ;
			my ($tmp) = @$data{$xname} ;
			$data->{$tmp} = $xtotal ;

			return 0;
		},
		FILENAME_SUFFIX => 'PZ',
		PRODUCE_PIF => 0,
		PRODUCE_LIF => 'True',
	},

	{
		RULE_TYPE => 'PIF_2_LIF',
		RULE_NAME => 'SUBX',
		INPUT_FILE_DESCRIPTION => "^SUBX.*-#-I.pif\$",
		PRODUCE_PIF => 0,
		PRODUCE_LIF => 'TRUE',
	},

	{
                RULE_TYPE => 'FILE_SPLIT',
                RULE_DESC => 'To split GPXX PIF',
                INPUT_FILE_DESCRIPTION => '^GPXX.*pif$',
                COUNTERS_USED_TO_SPLIT_FILE => {
                        TIME => '(.*)',
                },
                SPLIT_COUNTERS_ORDER => [qw(TIME)],
                OUTPUT_BLOCK_NAME => 'GPXX',
                PRODUCE_PIF => 'True',
                PRODUCE_LIF => 'True',
        },
 
	{
                RULE_TYPE => 'ACCUMULATE',
                RULE_DESC => 'Aggregation of GPXX block from Processor Level to MSC Level',
                INPUT_FILE_DESCRIPTION => ['^GPXX-#-.*-#-I-#-.*-#-FS\.pif$'],
                COUNTERS_TO_SORT_ON => [qw(EXCH_ID START_DATE TIME)],
                NON_ADDITIVE_COUNTERS => [qw(AVAILABILITY DATA_QUALITY)],
                REDUNDANT_COUNTERS => ['LTG'],
                OUTPUT_BLOCK_NAME => 'GPXXNODE',
                OUTPUT_FILENAME_START => 'GPXXNODE',
                PRODUCE_PIF => 0,
                PRODUCE_LIF => 'True',
        },
	
	{
                RULE_TYPE => 'PIF_2_OUTPUT',
                RULE_DESC => 'Convert all TRFL PIFs and LIF',
                INPUT_FILE_DESCRIPTION => '^TRFL.*pif$',
                OUTPUT_BLOCK_NAME => 'TRFL',
                PRODUCE_PIF => 0,
                PRODUCE_LIF => 'True',
                OUTPUT_FORMAT => 'LIF_Writer',
        },
	
	{
                RULE_TYPE => 'FILE_SPLIT',
                RULE_NAME => 'To split LTGX PIF',
                INPUT_FILE_DESCRIPTION => '^LTGX.*pif$',
                COUNTERS_USED_TO_SPLIT_FILE => {
                        TIME => '(\d{2}):\d{2}',
                },
                SPLIT_COUNTERS_ORDER => [ qw(TIME) ],
                OUTPUT_BLOCK_NAME => 'LTGX',
                PRODUCE_PIF => 'True',
                PRODUCE_LIF => 0,
        },
	
        {
                RULE_TYPE => 'MERGELINES',
                RULE_NAME => 'LTGX Trunk Group Statistics',
                INPUT_FILE_DESCRIPTION => ['^LTGX.*-#-FS\.pif$'],
                COUNTERS_TO_SORT_ON => ['START_DATE', 'TIME', 'LTG'],
                REDUNDANT_COUNTERS => ['INDEX'],
                PRODUCE_LIF => 'True',
                PRODUCE_PIF => 0,
        },

	{
		RULE_TYPE => 'CPXX_NORMALIZE',
		RULE_NAME => 'Central Processor Stats',
		INPUT_FILE_DESCRIPTION => '^CPXX-#-.*I\.pif$',
		REDUNDANT_COUNTERS => [qw(DATA_QUALITY DATA_LENGTH END_TIME)],
		OUTPUT_BLOCK_NAME => 'PROC',
		PRODUCE_PIF => 'True',
		PRODUCE_LIF => 0,
	},

	{
		RULE_TYPE => 'ACCUMULATE',
		RULE_DESC => 'Aggregation of (CPXX) block',
		OUTPUT_BLOCK_NAME => 'PROC',
		INPUT_FILE_DESCRIPTION => ['^CPXX-#-.*-#-I-#-CP\.pif'],
		COUNTERS_TO_SORT_ON => [qw(START_DATE TIME NODEID )],
		NON_ADDITIVE_COUNTERS => [qw(EXCH_ID AVAILABILITY DATA_QUALITY DATA_LENGTH INTEGRATION_FACTOR END_TIME)],
		AVERAGE_COUNTERS => [qw(CARRIED_TRAFFIC TOTAL_INTENSITY )],
		MAXIMUM_COUNTERS => [qw(CARRIED_TRAFFIC TOTAL_INTENSITY)],
		MINIMUM_COUNTERS => [qw(CARRIED_TRAFFIC TOTAL_INTENSITY)],
		APPEND_STR => '_SUM',
		MAXIMUM_APPEND_STR => '_MAX',
		MINIMUM_APPEND_STR => '_MIN',
		AVERAGE_APPEND_STR => '_AVG',
		PRODUCE_PIF => 'True',
		PRODUCE_LIF => 0,
	},

	{
		RULE_TYPE => 'PERLIZE',
		RULE_DESC => 'Further processing of PROC(CPXX) block',
		OUTPUT_BLOCK_NAME => 'PROC',
		INPUT_FILE_DESCRIPTION => ['CPXX-#-.*-#-CP-#-PROC-#-A.pif$'],
		DATA_COUNTERS_OP => sub {
			my $href = shift;
			
			foreach my $cname (grep /(.*)_(MIN|MAX|AVG|SUM)$/, keys %$href) {
				SWITCH: {
					$cname =~ /^.*_NUM_IN_SUM$/ and do {
						last;
					};
					$cname =~ /(.*)_(MIN|MAX|AVG)$/ and do {
						$href->{$2 . '_' . $1} = $href->{$cname};
						delete $href->{$cname};
						last;
					};
					$cname =~ /(.*)_SUM$/ and do {
						$href->{$1} = $href->{$cname};
						delete $href->{$cname};
						last;
					};
				}
			}
			
			return 0;
		},
		FILENAME_SUFFIX => 'PZ',
		PRODUCE_PIF => 'True',
		PRODUCE_LIF => 'True',
	},
		
	{
		RULE_TYPE => 'ACCUMULATE',
		RULE_DESC => 'Aggregation of PROC(CPXX) block from Processor Level to Parent Level',
		OUTPUT_BLOCK_NAME => 'CPXXNODE',
		OUTPUT_FILENAME_START => 'CPXXNODE',
		INPUT_FILE_DESCRIPTION => ['^CPXX-#-.*-#-I-#-CP-#-PROC-#-A-#-PZ\.pif'],
		COUNTERS_TO_SORT_ON => [qw(EXCH_ID START_DATE TIME)],
		NON_ADDITIVE_COUNTERS => [qw(NODEID AVAILABILITY DATA_LENGTH DATA_QUALITY INTEGRATION_FACTOR END_TIME)],
		REDUNDANT_DATA_COUNTERS => [qw(NODEID MAX_TOTAL_INTENSITY MIN_TOTAL_INTENSITY MAX_CARRIED_TRAFFIC MIN_CARRIED_TRAFFIC AVG_TOTAL_INTENSITY AVG_CARRIED_TRAFFIC)],
		AVERAGE_COUNTERS => [qw(CARRIED_TRAFFIC TOTAL_INTENSITY)],
		MAXIMUM_COUNTERS => [qw(CARRIED_TRAFFIC TOTAL_INTENSITY)],
		MINIMUM_COUNTERS => [qw(CARRIED_TRAFFIC TOTAL_INTENSITY)], 
		APPEND_STR => '_SUM',
		AVERAGE_APPEND_STR => '_AVG',
		MAXIMUM_APPEND_STR => '_MAX',
		MINIMUM_APPEND_STR => '_MIN',
		PRODUCE_PIF => 'True',
		PRODUCE_LIF => 0,
	},
	
	{	   
		RULE_TYPE => 'INFOINSERT',
		RULE_DESC => 'INFOINSERT NODE_TYPE TO CPXX block',
		INPUT_FILE_DESCRIPTION => ['CPXX-#-.*-#-CPXXNODE-#-A.pif$'],
		HEADER_NAMES_USED_TO_ID_DATA_RECORD => [],
		NAMES_USED_TO_ID_DATA_RECORD => ['EXCH_ID'],
		INFO_FILE_DESCRIPTION => ['^CPXX_NODE_TYPE.txt.*-#-I.pif$'],
		HEADER_NAMES_USED_TO_ID_INFORMATION => [],
		NAMES_USED_TO_ID_INFORMATION => ['EXCH_ID'],
		OUTPUT_BLOCK_NAME => 'PROC',
		REDUNDANT_DATA_COUNTERS => [],
		ONLY_INSERT => ['NODE_TYPE'],
		WRITE_DATA_LINE => 'True',
		PRODUCE_PIF => 'True',
		PRODUCE_LIF => 0,
		REMOVE_INFO_FILES => 0,
	},
	
	{
		RULE_TYPE => 'PERLIZE',
		RULE_DESC => 'Further processing of PROC(CPXX) block',
		OUTPUT_BLOCK_NAME => 'CPXXNODE',
		OUTPUT_FILENAME_START => 'CPXXNODE', 
		INPUT_FILE_DESCRIPTION => ['CPXX-#-.*-#-CPXXNODE-#-A-#-S\.pif$'], 
		DATA_COUNTERS_OP => sub {
			my $href = shift;
			
			foreach my $cname (grep /(.*)_(MIN|MAX|AVG|SUM)$/, keys %$href) {
				SWITCH: {
					$cname =~ /^.*_NUM_IN_SUM$/ and do {
						last;
					};
					$cname =~ /(.*)_(MIN|MAX|AVG)$/ and do {
						$href->{$2 . '_' . $1} = $href->{$cname};
						delete $href->{$cname};
						last;
					};
					$cname =~ /(.*)_SUM$/ and do {
						$href->{$1} = $href->{$cname};
						delete $href->{$cname};
						last;
					};
				}
			}
	
			return 0;
		},	
		FILENAME_SUFFIX => 'PZ',
		OUTPUT_BLOCK_NAME => 'CPXXNODE',
		PRODUCE_PIF => 'True',
		PRODUCE_LIF => 'LIF_Writer',
	},
	
	{
		RULE_TYPE => 'FILE_SPLIT',
		RULE_DESC => 'To split CPXX PIF',
		INPUT_FILE_DESCRIPTION => 'CPXX-#-.*-#-CPXXNODE-#-A-#-S-#-PZ\.pif$',
		COUNTERS_USED_TO_SPLIT_FILE => {
			NODE_TYPE => '(.*)',
		},
		SPLIT_COUNTERS_ORDER => [qw(NODE_TYPE)],
		OUTPUT_BLOCK_NAME => 'CPXX',
		PRODUCE_PIF => 'True',
		PRODUCE_LIF => 0,
	},
	
	{
		RULE_TYPE => 'PERLIZE',
		RULE_DESC => 'Further processing of CPXXNODE block',
		INPUT_FILE_DESCRIPTION => ['CPXX-#-.*-#-CPXXNODE-#-A-#-S-#-PZ-#-MSC-#-FS\.pif$'], 
		DATA_COUNTERS_OP => sub {
			my $href = shift;
			
			if (exists($href->{CPXXNODE_NUM_IN_SUM})) {
				$href->{CPXXMSC_NUM_IN_SUM} = $href->{CPXXNODE_NUM_IN_SUM};
				delete $href->{CPXXNODE_NUM_IN_SUM};
			}

			return 0;
		},	
		FILENAME_SUFFIX => 'PZ',
		OUTPUT_BLOCK_NAME => 'CPXXMSC',
		OUTPUT_FILENAME_START => 'CPXXMSC', 
		PRODUCE_PIF => 'True',
		PRODUCE_LIF => 'LIF_Writer',
	},
	
	{	
		RULE_TYPE => 'PERLIZE',
		RULE_DESC => 'Further processing of CPXXNODE block',
		INPUT_FILE_DESCRIPTION => ['CPXX-#-.*-#-CPXXNODE-#-A-#-S-#-PZ-#-HLR-#-FS\.pif$'], 
		DATA_COUNTERS_OP => sub {
			my $href = shift;
			
			if (exists($href->{CPXXNODE_NUM_IN_SUM})) {
				$href->{CPXXHLR_NUM_IN_SUM} = $href->{CPXXNODE_NUM_IN_SUM};
				delete $href->{CPXXNODE_NUM_IN_SUM};
			}
	
			return 0;
		},	
		FILENAME_SUFFIX => 'PZ',
		OUTPUT_BLOCK_NAME => 'CPXXHLR',
		OUTPUT_FILENAME_START => 'CPXXHLR', 
		PRODUCE_PIF => 'True',
		PRODUCE_LIF => 'LIF_Writer',
	},

	{
		RULE_TYPE => 'MERGELINES',
		RULE_NAME => 'TGRP Trunk Group Statistics',
		INPUT_FILE_DESCRIPTION => ['^TGRP-#-.*-#-I\.pif$'],
		COUNTERS_TO_SORT_ON => ['START_DATE', 'TIME', 'TGNO'],
		REDUNDANT_COUNTERS => ['INDEX'],
		PRODUCE_LIF => 'True',
		PRODUCE_PIF => 0,
	},
	
);

#-------------------------------------------------------------------------------

sub postparser_config{
	return \@rules;
}

1;

